--
-- moveCutNode V3
-- Specialization for moving the cutNode to give a new dimension to the cutNode
--
-- author: Patar (Thomas Heck)
-- date: 28.01.15
--
-- extended V2: 01.09.2015/Patar
-- V3 (conversion to FS17): 02.11.16/Patar

moveCutNode = {};

function moveCutNode.prerequisitesPresent(specializations)
    return true;
end;

function moveCutNode:load(savegame)
-- general
    self.moveMinZ = Utils.getNoNil(getXMLFloat(self.xmlFile, "vehicle.stumpCutter#moveMinZ"), -1);
    self.moveMaxZ = Utils.getNoNil(getXMLFloat(self.xmlFile, "vehicle.stumpCutter#moveMaxZ"), 1);
    self.moveStep = 0.15;
    
-- first line (cutted wood etc.)
    local x, y, z = getTranslation(self.stumpCutterCutNode);
    self.firstLineY = y; self.firstLineX = x;
	
    local xRot, yRot, zRot = getRotation(self.stumpCutterCutNode);
    self.firstLineXRot = xRot; self.firstLineYRot = yRot; self.firstLineZRot = zRot;
	
    self.firstLineCutSizeZ = self.stumpCutterCutSizeZ;
	
-- second line (stumps)
    self.isSecondLine = false;
	
    self.secondLineY = Utils.getNoNil(getXMLFloat(self.xmlFile, "vehicle.stumpCutter#secondLineY"), -1);
    self.secondLineX = Utils.getNoNil(getXMLFloat(self.xmlFile, "vehicle.stumpCutter#secondLineX"), -1);
	
	self.secondLineCutSizeZ = Utils.getNoNil(getXMLFloat(self.xmlFile, "vehicle.stumpCutter#secondLineCutSizeZ"), 1);
	
    self.secondLineXRot = Utils.getNoNil(getXMLFloat(self.xmlFile, "vehicle.stumpCutter#secondLineXRot"), 0);
    self.secondLineYRot = Utils.getNoNil(getXMLFloat(self.xmlFile, "vehicle.stumpCutter#secondLineYRot"), 0);
    self.secondLineZRot = Utils.getNoNil(getXMLFloat(self.xmlFile, "vehicle.stumpCutter#secondLineZRot"), 0);
    

    
end;

function moveCutNode:delete()
end;

function moveCutNode:mouseEvent(posX, posY, isDown, isUp, button)
end;

function moveCutNode:keyEvent(unicode, sym, modifier, isDown)
end;

function moveCutNode:update(dt)
    if self:getIsTurnedOn() then
        if not self.stumpCutterParticleSystems[1].isEmitting then
            local x,y,z = getTranslation(self.stumpCutterCutNode);
            if z > self.moveMaxZ or z < self.moveMinZ then
                self.isSecondLine = not self.isSecondLine;
                self.moveStep = -self.moveStep;
            end;
            z = z + self.moveStep;
            if self.isSecondLine then
				self.stumpCutterCutSizeZ = self.secondLineCutSizeZ;
                y = self.secondLineY; x = self.secondLineX;
                setRotation(self.stumpCutterCutNode, math.rad(self.secondLineXRot), math.rad(self.secondLineYRot), math.rad(self.secondLineZRot));
            else
				self.stumpCutterCutSizeZ = self.firstLineCutSizeZ;
                y = self.firstLineY; x = self.firstLineX;
                setRotation(self.stumpCutterCutNode, self.firstLineXRot, self.firstLineYRot, self.firstLineZRot);
            end;
            setTranslation(self.stumpCutterCutNode, x, y, z);
        end;
		if self.isSecondLine then
			if self.curSplitShape ~= nil and self.isServer then
				x1, y1, z1 = getWorldTranslation(self.curSplitShape);
				x1, y1, z1 = worldToLocal(getParent(getParent(self.stumpCutterParticleSystems[1].emitterShape)), x1, y1, z1);
				local origX, origY, origZ = getTranslation(getParent(self.stumpCutterParticleSystems[1].emitterShape));
				setTranslation(getParent(self.stumpCutterParticleSystems[1].emitterShape), origX, origY, math.max(math.min(z1, self.moveMaxZ),self.moveMinZ));
			end;
			if self.isClient and not self.isServer then
				local moveX, moveY, moveZ = getTranslation(self.stumpCutterParticleSystems[1].emitterShape);
				setTranslation(getParent(self.stumpCutterParticleSystems[1].emitterShape), moveX, moveY, 0);
			end;
		else
			local moveX, moveY, moveZ = getTranslation(self.stumpCutterCutNode);
			local origX, origY, origZ = getTranslation(getParent(self.stumpCutterParticleSystems[1].emitterShape));
			setTranslation(getParent(self.stumpCutterParticleSystems[1].emitterShape), origX, origY, moveZ-self.stumpCutterCutSizeZ/2);
		end;
    end;
end;

function moveCutNode:updateTick(dt)
end;

function moveCutNode:draw()
end;

function moveCutNode:onEnter()
end;
